<?php namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Plugin as ElementorPlugin;

/**
 * CleverBanner
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverBanner extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-banner';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Banner', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-banner';
    }

    /**
     * Register controls
     */
    protected function _register_controls()
    {
        $this->start_controls_section('clever_banner_image__settings', [
            'label' => __('Image', 'cafe')
        ]);

        $this->add_control('image', [
            'label' => __('Upload Image', 'cafe'),
            'description' => __('Select an image for the banner.', 'cafe'),
            'type' => Controls_Manager::MEDIA,
            'dynamic' => ['active' => true],
            'show_external' => true,
            'default' => [
                'url' => ''
            ]
        ]);
        $this->add_control('auto_size', [
            'label' => __('Auto Size', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'description' => __('Size of banner will apply follow image size.', 'cafe'),
            'return_value' => 'true',
            'default' => 'true',
        ]);
        $this->add_responsive_control('custom_height', [
            'label' => __('Height', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'desktop_default' => '300',
            'tablet_default' => '300',
            'mobile_default' => '300',
            'description' => __('Custom height of banner.', 'cafe'),
            'condition' => [
                'auto_size' => ''
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-image' => 'height: {{VALUE}}px'
            ]
        ]);
        $this->add_control('link', [
            'label' => __('Link', 'cafe'),
            'type' => Controls_Manager::URL,
            'description' => __('Redirect link when click to banner.', 'cafe'),
        ]);

        $this->add_control('css_class', [
            'label' => __('Custom HTML Class', 'cafe'),
            'type' => Controls_Manager::TEXT,
            'description' => __('You may add a custom HTML class to style element later.', 'cafe'),
        ]);

        $this->end_controls_section();

        $this->start_controls_section('content_settings', [
            'label' => __('Content', 'cafe')
        ]);

        $this->add_control('title', [
            'label' => __('Title', 'cafe'),
            'placeholder' => __('What is the title of this banner.', 'cafe'),
            'description' => __('What is the title of this banner.', 'cafe'),
            'type' => Controls_Manager::TEXTAREA,
            'dynamic' => ['active' => true],
            'default' => __('Clever Banner', 'cafe'),
            'label_block' => true
        ]);

        $this->add_control('title_tag',
            [
                'label' => __('HTML Tag', 'cafe'),
                'description' => __('Select a heading tag for the title. Headings are defined with H1 to H6 tags.', 'cafe'),
                'type' => Controls_Manager::SELECT,
                'default' => 'h3',
                'options' => [
                    'h1' => 'H1',
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6'
                ],
                'label_block' => true,
            ]);
        $this->add_control('description_heading', [
            'label' => __('Description', 'cafe'),
            'type' => Controls_Manager::HEADING
        ]);

        $this->add_control('des', [
            'label' => __('Description', 'cafe'),
            'description' => __('Give a description to this banner.', 'cafe'),
            'type' => Controls_Manager::WYSIWYG,
            'dynamic' => ['active' => true],
            'default' => __('A web banner or banner ad is a form of advertising. It is intended to attract traffic to a website by linking to the website of the advertiser. - Wikipedia', 'cafe'),
            'label_block' => true
        ]);
        $this->end_controls_section();
        $this->start_controls_section('button_settings', [
            'label' => __('Button', 'cafe')
        ]);
        $this->add_control('button_label', [
            'label' => __('Button Label', 'cafe'),
            'placeholder' => __('Button', 'cafe'),
            'description' => __('Leave it blank if don\'t use it', 'cafe'),
            'type' => Controls_Manager::TEXT,
            'dynamic' => ['active' => true],
            'default' => __('Button', 'cafe'),
            'label_block' => false
        ]);
        $this->add_control('button_icon', [
            'label' => __('Icon', 'cafe'),
            'type' => 'clevericon'
        ]);
        $this->add_control('button_icon_pos', [
            'label' => __('Icon position', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'after',
            'options' => [
                'before' => __('Before', 'cafe'),
                'after' => __('After', 'cafe'),
            ]
        ]);
        $this->add_control('button_style', [
            'label' => __('Button style', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'normal',
            'options' => [
                'normal' => __('Normal', 'cafe'),
                'underline' => __('Underline', 'cafe'),
                'outline' => __('Outline', 'cafe'),
            ]
        ]);
        $this->end_controls_section();
        $this->start_controls_section('normal_style_settings', [
            'label' => __('Normal', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('overlay_banner', [
            'label' => __('Overlay banner', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'description' => __('Content will show up on image banner.', 'cafe'),
            'return_value' => 'true',
            'default' => 'true',
        ]);
        $this->add_control('effect', [
            'label' => __('Hover Effect', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'normal',
            'condition' => [
                'overlay_banner' => 'true'
            ],
            'options' => [
                'normal' => __('Normal', 'cafe'),
                'lily' => __('Lily', 'cafe'),
                'layla' => __('Layla', 'cafe'),
                'sadie' => __('Sadie', 'cafe'),
                'oscar' => __('Oscar', 'cafe'),
                'oscar-2' => __('Oscar 2', 'cafe'),
                'chico' => __('Chico', 'cafe'),
                'ruby' => __('Ruby', 'cafe'),
                'roxy' => __('Roxy', 'cafe'),
                'marley' => __('Marley', 'cafe'),
                'sarah' => __('Sarah', 'cafe'),
                'milo' => __('Milo', 'cafe'),
                'overlay-box' => __('Overlay box', 'cafe'),
            ]
        ]);
        $this->add_responsive_control(
            'text_align',
            [
                'label' => __('Text Align', 'cafe'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __('Left', 'cafe'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'center' => __('Center', 'cafe'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'cafe'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cafe-wrap-content' => 'text-align: {{VALUE}};'
                ]
            ]
        );
        $this->add_control( 'content_align', [
            'label'                => __( 'Vertical Align', 'cafe' ),
            'type'                 => Controls_Manager::CHOOSE,
            'label_block'          => false,
            'options'              => [
                'top'    => [
                    'title' => __( 'Top', 'cafe' ),
                    'icon'  => 'eicon-v-align-top',
                ],
                'center' => [
                    'title' => __( 'Middle', 'cafe' ),
                    'icon'  => 'eicon-v-align-middle',
                ],
                'bottom' => [
                    'title' => __( 'Bottom', 'cafe' ),
                    'icon'  => 'eicon-v-align-bottom',
                ],
            ],
            'condition' => [
                'overlay_banner' => 'true'
            ],
            'selectors'            => [
                '{{WRAPPER}} .cafe-wrap-content' => 'justify-content: {{VALUE}};'
            ],
            'selectors_dictionary' => [
                'top'    => 'flex-start',
                'center' => 'center',
                'bottom' => 'flex-end',
            ],
        ] );
        $this->add_responsive_control('dimensions', [
            'label' => __('Dimensions', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
	    $this->add_responsive_control('border_radius', [
		    'label' => __('Border Radius', 'cafe'),
		    'type' => Controls_Manager::DIMENSIONS,
		    'size_units' => ['px', '%'],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-wrap-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		    ],
	    ]);
        $this->add_control(
            'title_color_divider',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        $this->add_control('title_color_heading', [
            'label' => __('Title', 'cafe'),
            'type' => Controls_Manager::HEADING
        ]);
        $this->add_control('title_color', [
            'label' => __('Title Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner-title, {{WRAPPER}} .cafe-wrap-content' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'selector' => '{{WRAPPER}} .cafe-banner-title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
            ]
        );
	    $this->add_control( 'title_space', [
		    'label'     => __( 'Space', 'cafe' ),
		    'type'      => Controls_Manager::SLIDER,
		    'range'     => [
			    'px' => [
				    'min' => 0,
				    'max' => 100,
			    ],
		    ],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-banner .cafe-banner-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
		    ],
	    ] );
        $this->add_control(
            'des_color_divider',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        $this->add_control('des_color_heading', [
            'label' => __('Description', 'cafe'),
            'type' => Controls_Manager::HEADING
        ]);
        $this->add_control('des_color', [
            'label' => __('Description Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner .cafe-banner-description' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'des_typography',
                'selector' => '{{WRAPPER}} .cafe-banner .cafe-banner-description',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
            ]
        );
	    $this->add_control( 'des_space', [
		    'label'     => __( 'Space', 'cafe' ),
		    'type'      => Controls_Manager::SLIDER,
		    'range'     => [
			    'px' => [
				    'min' => 0,
				    'max' => 100,
			    ],
		    ],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-banner .cafe-banner-description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
		    ],
	    ] );
        $this->add_control(
            'button_style_divider',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        $this->add_control('button_style_heading', [
            'label' => __('Button', 'cafe'),
            'type' => Controls_Manager::HEADING
        ]);
        $this->add_control('button_color', [
            'label' => __('Button Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner .cafe-button' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('button_bg', [
            'label' => __('Button Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner .cafe-button.outline::after,{{WRAPPER}}  .cafe-banner .cafe-button.normal' => 'background: {{VALUE}};'
            ]
        ]);
	    $this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
			    'name' => 'button_typography',
			    'selector' => '{{WRAPPER}} .cafe-banner .cafe-button',
			    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
		    ]
	    );
	    $this->add_responsive_control('button_spacing', [
		    'label' => __('Spacing', 'cafe'),
		    'type' => Controls_Manager::DIMENSIONS,
		    'size_units' => ['px', '%', 'em'],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-banner .cafe-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		    ],
	    ]);
	    $this->add_responsive_control('button_border_radius', [
		    'label' => __('Border Radius', 'cafe'),
		    'type' => Controls_Manager::DIMENSIONS,
		    'size_units' => ['px', '%'],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-banner .cafe-button,{{WRAPPER}} .cafe-banner .cafe-button:before,{{WRAPPER}} .cafe-banner .cafe-button:after' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		    ],
	    ]);

        $this->add_control('overlay_bg_heading', [
            'label' => __('Background Overlay', 'cafe'),
            'type' => Controls_Manager::HEADING
        ]);
        $this->add_control(
            'overlay_bg_divider',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_bg',
                'label' => __('Background Overlay', 'cafe'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cafe-wrap-content',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section('hover_style_settings', [
            'label' => __('Hover', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('title_color_hover', [
            'label' => __('Title Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner:hover .cafe-wrap-content,{{WRAPPER}} .cafe-banner.cafe-overlay-content:hover .cafe-banner-title, {{WRAPPER}} .cafe-banner:not(.cafe-overlay-content) .cafe-banner-title:hover' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('des_color_hover', [
            'label' => __('Description Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner.cafe-overlay-content:hover .cafe-banner-description,{{WRAPPER}} .cafe-banner:not(.cafe-overlay-content) .cafe-banner-description:hover' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('button_color_hover', [
            'label' => __('Button Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner .cafe-button:hover' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('button_bg_hover', [
            'label' => __('Button Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-banner .cafe-button.outline:hover:after,{{WRAPPER}}  .cafe-banner .cafe-button.normal:hover' => 'background: {{VALUE}};'
            ]
        ]);
        $this->add_control(
            'overlay_bg_hover_divider',
            [
                'type' => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        $this->add_control('overlay_bg_hover_heading', [
            'label' => __('Background Overlay', 'cafe'),
            'type' => Controls_Manager::HEADING
        ]);
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'overlay_bg_hover',
                'label' => __('Background Overlay', 'cafe'),
                'types' => ['classic', 'gradient'],
                'selector' => '{{WRAPPER}} .cafe-banner.cafe-overlay-content:hover .cafe-wrap-content',
            ]
        );
        $this->end_controls_section();
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
            'image' => CAFE_URI . 'assets/img/banner-placeholder.png',
            'auto_size' => 'true',
            'link' => '',
            'css_class' => '',
            'title' => '',
            'title_tag' => 'h3',
            'des' => '',
            'button_label' => '',
            'button_icon' => '',
            'button_icon_pos' => 'after',
            'button_style' => 'normal',
            'overlay_banner' => 'true',
            'effect' => 'normal',
        ], $this->get_settings_for_display());

        $this->add_inline_editing_attributes('title');
        $this->add_inline_editing_attributes('description');
        $this->add_inline_editing_attributes('button_label');

        $des_html_classes = ['cafe-banner-description'];
        $title_html_classes = ['cafe-banner-title'];
        $button_html_classes = [ 'cafe-button ' . $settings['button_style']];

        if (ElementorPlugin::$instance->editor->is_edit_mode()) {
            $des_html_classes[] = 'cafe-draggable-element';
            $title_html_classes[] = 'cafe-draggable-element';
            $button_html_classes[] = 'cafe-draggable-element';
        }

        $this->add_render_attribute('title', 'class', $title_html_classes);
        $this->add_render_attribute('des', 'class', $des_html_classes);
        $this->add_render_attribute('button_label', 'class', $button_html_classes);

        $this->getViewTemplate('template', 'banner', $settings);
    }
}
