<?php namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;

/**
 * CleverButton
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverButton extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-button';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Button', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-button';
    }

    /**
     * Register controls
     */
    protected function _register_controls()
    {
        $this->start_controls_section('button_settings', [
            'label' => __('Button', 'cafe')
        ]);
        $this->add_control('button_label', [
            'label' => __('Button Label', 'cafe'),
            'placeholder' => __('Button', 'cafe'),
            'type' => Controls_Manager::TEXT,
            'dynamic' => ['active' => true],
            'default' => __('Button', 'cafe'),
            'label_block' => false
        ]);
        $this->add_control('button_icon', [
            'label' => __('Icon', 'cafe'),
            'type' => 'clevericon'
        ]);
        $this->add_control('button_icon_pos', [
            'label' => __('Icon position', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'after',
            'options' => [
                'before' => __('Before', 'cafe'),
                'after' => __('After', 'cafe'),
            ]
        ]);
	    $this->add_control('link', [
		    'label' => __('Link', 'cafe'),
		    'type' => Controls_Manager::URL,
		    'description' => __('Redirect link when click to banner.', 'cafe'),
		    'separator'   => 'after',
	    ]);
	    $this->add_control('css_class', [
		    'label' => __('Custom HTML Class', 'cafe'),
		    'type' => Controls_Manager::TEXT,
		    'description' => __('You may add a custom HTML class to style element later.', 'cafe'),
	    ]);
        $this->end_controls_section();
        $this->start_controls_section('normal_style_settings', [
            'label' => __('Normal', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
	    $this->add_control('button_style', [
		    'label' => __('Button style', 'cafe'),
		    'type' => Controls_Manager::SELECT,
		    'default' => 'normal',
		    'options' => [
			    'normal' => __('Normal', 'cafe'),
			    'underline' => __('Underline', 'cafe'),
			    'outline' => __('Outline', 'cafe'),
			    'flat' => __('Flat', 'cafe'),
			    'slide' => __('Slide', 'cafe'),
		    ]
	    ]);
	    $this->add_responsive_control(
		    'text_align',
		    [
			    'label' => __('Button Align', 'cafe'),
			    'type' => Controls_Manager::CHOOSE,
			    'options' => [
				    'left' => [
					    'title' => __('Left', 'cafe'),
					    'icon' => 'fa fa-align-left',
				    ],'center' => [
					    'title' => __('Center', 'cafe'),
					    'icon' => 'fa fa-align-center',
				    ],
				    'right' => [
					    'title' => __('Right', 'cafe'),
					    'icon' => 'fa fa-align-right',
				    ],
			    ],
			    'selectors' => [
				    '{{WRAPPER}}' => 'text-align: {{VALUE}};'
			    ]
		    ]
	    );
	    $this->add_control('button_color', [
		    'label' => __('Button Color', 'cafe'),
		    'type' => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .cafe-button' => 'color: {{VALUE}};'
		    ]
	    ]);
	    $this->add_control('button_bg', [
		    'label' => __('Button Background', 'cafe'),
		    'type' => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .cafe-button:after,{{WRAPPER}} .cafe-button:before' => 'background: {{VALUE}};'
		    ]
	    ]);
	    $this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
			    'name' => 'button_typography',
			    'selector' => '{{WRAPPER}} .cafe-button',
			    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
		    ]

	    );

	    $this->add_control('button_border', [
		    'separator'   => 'before',
		    'label' => __('Button Border', 'cafe'),
		    'type' => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .cafe-button:before' => 'border-color: {{VALUE}};'
		    ]
	    ]);
	    $this->add_responsive_control('border_radius', [
		    'label' => __('Border Radius', 'cafe'),
		    'type' => Controls_Manager::DIMENSIONS,
		    'size_units' => ['px', '%'],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-button,{{WRAPPER}} .cafe-button:after,{{WRAPPER}} .cafe-button:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		    ],
	    ]);
	    $this->add_group_control(
		    Group_Control_Box_Shadow::get_type(),
		    [
			    'name' => 'button_box_shadow',
			    'selector' => '{{WRAPPER}} .cafe-button',
		    ]
	    );
	    $this->add_responsive_control('dimensions', [
		    'label' => __('Padding', 'cafe'),
		    'type' => Controls_Manager::DIMENSIONS,
		    'size_units' => ['px', '%', 'em'],
		    'separator'   => 'before',
		    'selectors' => [
			    '{{WRAPPER}} .cafe-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		    ],
	    ]);
        $this->end_controls_section();

        $this->start_controls_section('hover_style_settings', [
            'label' => __('Hover', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('button_color_hover', [
            'label' => __('Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-button:hover' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('button_bg_hover', [
            'label' => __('Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
	            '{{WRAPPER}} .cafe-button:hover:after,{{WRAPPER}} .cafe-button:hover:before'  => 'background-color: {{VALUE}};',
	            ]
        ]);
        $this->add_control('button_border_hover', [
            'label' => __('Border Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
	            '{{WRAPPER}} .cafe-button:hover:before'  => 'border-color: {{VALUE}};'
	            ]
        ]);
	    $this->add_group_control(
		    Group_Control_Box_Shadow::get_type(),
		    [
			    'name' => 'button_box_shadow_hover',
			    'selector' => '{{WRAPPER}} .cafe-button:hover',
		    ]
	    );
        $this->end_controls_section();
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
            'link' => '',
            'css_class' => '',
            'button_label' => '',
            'button_icon' => '',
            'button_icon_pos' => 'after',
            'button_style' => 'normal',
        ], $this->get_settings_for_display());

        $this->add_inline_editing_attributes('button_label');

        $button_class = 'cafe-button ' . $settings['button_style'].' '.$settings['css_class'];
        $this->add_render_attribute('button_label', 'class', $button_class);

        $this->getViewTemplate('template', 'button', $settings);
    }
}
