<?php namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Border;

/**
 * CleverIcon
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverIcon extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-icon';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Icon', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-small-diamond';
    }

    /**
     * Register controls
     */
    protected function _register_controls()
    {
        $this->start_controls_section('icon_settings', [
            'label' => __('Icon', 'cafe')
        ]);
        $this->add_control('icon', [
            'label' => __('Icon', 'cafe'),
            'default' => 'cs-font icon-plane-2',
            'type' => 'clevericon',
        ]);
	    $this->add_control('link', [
		    'label' => __('Link', 'cafe'),
		    'type' => Controls_Manager::URL,
		    'description' => __('Redirect link when click to icon.', 'cafe'),
	    ]);
	    $this->add_control('align', [
		    'label' => __('Alignment', 'cafe'),
		    'type' => Controls_Manager::CHOOSE,
		    'options' => [
			    'left'    => [
				    'title' => __( 'Left', 'elementor' ),
				    'icon' => 'fa fa-align-left',
			    ],
			    'center' => [
				    'title' => __( 'Center', 'elementor' ),
				    'icon' => 'fa fa-align-center',
			    ],
			    'right' => [
				    'title' => __( 'Right', 'elementor' ),
				    'icon' => 'fa fa-align-right',
			    ],
		    ],
		    'default' => 'center',
		    'selectors' => [
			    '{{WRAPPER}}' => 'text-align: {{VALUE}};',
		    ],
	    ]);
	    $this->add_control('css_class', [
		    'label' => __('Custom HTML Class', 'cafe'),
		    'type' => Controls_Manager::TEXT,
		    'description' => __('You may add a custom HTML class to style element later.', 'cafe'),
	    ]);
        $this->end_controls_section();
        $this->start_controls_section('normal_style_settings', [
            'label' => __('Normal', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
	    $this->add_control('icon_size', [
		    'label' => __('Icon size', 'cafe'),
		    'type' => Controls_Manager::SLIDER,
		    'range' => [
			    'px' => [
				    'min' => 0,
				    'max' => 100,
			    ],
		    ],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-icon' => 'font-size: {{SIZE}}{{UNIT}};',
		    ],
	    ]);
	    $this->add_control('icon_block_size', [
		    'label' => __('Size', 'cafe'),
		    'type' => Controls_Manager::SLIDER,
		    'range' => [
			    'px' => [
				    'min' => 0,
				    'max' => 300,
			    ],
		    ],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-icon' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
		    ],
	    ]);
	    $this->add_control('color', [
		    'label' => __('Color', 'cafe'),
		    'type' => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .cafe-icon' => 'color: {{VALUE}};'
		    ]
	    ]);
	    $this->add_control('icon_bg', [
		    'label' => __('Icon Background', 'cafe'),
		    'type' => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .cafe-icon' => 'background: {{VALUE}};'
		    ]
	    ]);
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'icon_shadow',
                'separator' => 'before',
                'selector' => '{{WRAPPER}} .cafe-icon',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'icon_border',
                'label' => __('Border', 'cafe'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .cafe-icon',
                'separator' => 'before',
            ]
        );
        $this->add_responsive_control('padding', [
            'label' => __('Padding', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-icon' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
	    $this->add_responsive_control('border_radius', [
		    'label' => __('Border Radius', 'cafe'),
		    'type' => Controls_Manager::DIMENSIONS,
		    'size_units' => ['px', '%'],
		    'selectors' => [
			    '{{WRAPPER}} .cafe-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		    ],
	    ]);

        $this->end_controls_section();

        $this->start_controls_section('hover_style_settings', [
            'label' => __('Hover', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('color_hover', [
            'label' => __('Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-icon:hover' => 'color: {{VALUE}};'
            ]
        ]);
	    $this->add_control('border_color_hover', [
		    'label' => __('Border Color', 'cafe'),
		    'type' => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .cafe-icon:hover' => 'border-color: {{VALUE}};'
		    ]
	    ]);
        $this->add_control('icon_bg_hover', [
            'label' => __('Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-icon:hover' => 'background: {{VALUE}};'
            ]
        ]);
        $this->end_controls_section();
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
            'link' => '',
            'css_class' => '',
            'icon' => '',
        ], $this->get_settings_for_display());

        $this->getViewTemplate('template', 'icon', $settings);
    }
}
