<?php namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

/**
 * CleverImageComparison
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverImageComparison extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-image-comparison';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Image Comparison', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-banner';
    }

	/**
	 * @return script
	 */

	public function get_script_depends() {
		return [ 'event-move', 'twentytwenty' ];
	}

	/**
     * Register controls
     */
    protected function _register_controls()
    {
	    $this->start_controls_section( 'general', [
		    'label'       => __( 'General', 'cafe' ),
	    ] );
	    $this->add_control('orientation', [
		    'label' => __('Orientation', 'cafe'),
		    'type' => Controls_Manager::SELECT,
		    'default' => 'horizontal',
		    'options' => [
			    'horizontal' => __('Horizontal', 'cafe'),
			    'vertical' => __('Vertical', 'cafe')
		    ]
	    ]);
	    $this->add_control( 'before', [
		    'label'       => __( 'Before Image', 'cafe' ),
		    'separator'   => 'before',
		    'type' => Controls_Manager::HEADING,
	    ] );
	    $this->start_controls_tabs( 'before_tabs' );
	    $this->start_controls_tab( 'before_content', [ 'label' => __( 'Content', 'cafe' ) ] );
	    $this->add_control('before_image', [
		    'label' => __('Upload Image', 'cafe'),
		    'description' => __('Select an image for compare.', 'cafe'),
		    'type' => Controls_Manager::MEDIA,
		    'dynamic' => ['active' => true],
		    'show_external' => true,
		    'default' => [
			    'url' => CAFE_URI . 'assets/img/banner-placeholder.png'
		    ]
	    ]);
	    $this->add_control(
		    'before_title',
		    [
			    'label' => __('Title', 'cafe'),
			    'type' => Controls_Manager::TEXT,
			    'label_block' => true,
		    ]
	    );
	    $this->end_controls_tab();

	    $this->start_controls_tab( 'before_imagestyle', [ 'label' => __( 'Style', 'cafe' ) ] );
	    $this->add_control( 'before_title_color', [
		    'label'     => __( 'Color', 'cafe' ),
		    'type'      => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .twentytwenty-before-label:before' => 'color: {{VALUE}}',
		    ],
	    ] );

	    $this->add_control( 'before_grayscale', [
		    'label'      => __( 'Grayscale', 'cafe' ),
		    'type'       => Controls_Manager::SLIDER,
		    'size_units' => [ '%' ],
		    'range'      => [
			    '%' => [
				    'min' => 0,
				    'max' => 100,
			    ],
		    ],
		    'selectors'  => [
			    '{{WRAPPER}} image.before-img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
		    ],
	    ] );
	    $this->end_controls_tab();
	    $this->end_controls_tabs();
        $this->add_control( 'after', [
		    'label'       => __( 'After Image', 'cafe' ),
		    'separator'   => 'before',
		    'type' => Controls_Manager::HEADING,
	    ] );
	    $this->start_controls_tabs( 'after_tabs' );
	    $this->start_controls_tab( 'after_content', [ 'label' => __( 'Content', 'cafe' ) ] );
	    $this->add_control('after_image', [
		    'label' => __('Upload Image', 'cafe'),
		    'description' => __('Select an image for compare.', 'cafe'),
		    'type' => Controls_Manager::MEDIA,
		    'dynamic' => ['active' => true],
		    'show_external' => true,
		    'default' => [
			    'url' => CAFE_URI . 'assets/img/banner-placeholder.png'
		    ]
	    ]);
	    $this->add_control(
		    'after_title',
		    [
			    'label' => __('Title', 'cafe'),
			    'type' => Controls_Manager::TEXT,
			    'label_block' => true,
		    ]
	    );
	    $this->end_controls_tab();

	    $this->start_controls_tab( 'after_imagestyle', [ 'label' => __( 'Style', 'cafe' ) ] );
	    $this->add_control( 'after_title_color', [
		    'label'     => __( 'Color', 'cafe' ),
		    'type'      => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .twentytwenty-after-label:before' => 'color: {{VALUE}}',
		    ],
	    ] );

	    $this->add_control( 'after_grayscale', [
		    'label'      => __( 'Grayscale', 'cafe' ),
		    'type'       => Controls_Manager::SLIDER,
		    'size_units' => [ '%' ],
		    'range'      => [
			    '%' => [
				    'min' => 0,
				    'max' => 100,
			    ],
		    ],
		    'selectors'  => [
			    '{{WRAPPER}} img.after-img' => 'filter: grayscale({{SIZE}}{{UNIT}});',
		    ],
	    ] );
	    $this->end_controls_tab();
	    $this->end_controls_tabs();

        $this->end_controls_section();
	    $this->start_controls_section( 'Style settings', [
		    'label' => __( 'Style', 'cafe' ),
		    'tab' => Controls_Manager::TAB_STYLE,
	    ] );
	    $this->add_control( 'overlay_bg', [
		    'label'     => __( 'Overlay Background', 'cafe' ),
		    'type'      => Controls_Manager::COLOR,
		    'selectors' => [
			    '{{WRAPPER}} .twentytwenty-overlay' => 'background: {{COLOR}};',
		    ],
	    ] );
	    $this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
			    'name' => 'label_typography',
			    'selector' => '{{WRAPPER}} .twentytwenty-overlay>div:before',
			    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
		    ]

	    );
	    $this->end_controls_section();
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
	        'orientation'=>'horizontal',
            'before_image' =>  CAFE_URI . 'assets/img/banner-placeholder.png',
	        'before_title' =>'',
            'after_image' =>  CAFE_URI . 'assets/img/banner-placeholder.png',
	        'after_title' =>'',
        ], $this->get_settings_for_display());


        $this->getViewTemplate('template', 'image-comparison', $settings);
    }
}
