<?php 
namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;

/**
 * CleverInstagram
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */

final class CleverInstagram extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-instagram';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Instagram', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-landscape-image';
    }
    
    /**
     * Register controls
     */
    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_setting', [
                'label' => __('Settings', 'cafe')
            ]);

        $this->add_control('title', [
            'label'		    => __('Title', 'cafe'),
            'type'		    => Controls_Manager::TEXT,
            'default'       => __( 'CAFE Instagram', 'cafe' ),
        ]);
        $this->add_control('username', [
            'label'         => __('Instagram tag', 'cafe'),
            'type'          => Controls_Manager::TEXT,
        ]);
        $this->add_control('number', [
            'label'         => __('Photos count', 'cafe'),
            'type'          => Controls_Manager::NUMBER,
        ]);
        
        $this->add_control('img_size', [
            'label'         => __('Image size', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SELECT,
            'default'       => 'small',
            'options' => [
                'thumbnail'     => __( 'Thumbnail', 'cafe' ),
                'small'         => __( 'Small', 'cafe' ),
                'large'         => __( 'Large', 'cafe' ),
                'original'      => __( 'Original', 'cafe' ),
            ],
        ]);
        $this->add_control('show_likes', [
            'label'         => __('Show likes count', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
        ]);
        $this->add_control('show_comments', [
            'label'         => __('Show comments count', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
        ]);
        $this->add_control('show_type', [
            'label'         => __('Show icons type( image/video )', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
        ]);
        $this->add_control('show_time', [
            'label'         => __('Show time', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
        ]);
        $this->add_control('time_layout', [
            'label'         => __('Time layout', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SELECT,
            'default'       => 'elapsed',
            'options' => [
                'elapsed'   => __( 'Time elapsed', 'cafe' ),
                'date'      => __( 'Date', 'cafe' ),
            ],
            'condition'     => [
                'show_time' => 'true',
            ],
        ]);
        $this->add_control('date_format', [
            'label'         => __('Date format', 'cafe'),
            'type'          => Controls_Manager::TEXT,
            'description'   => __('Ex: F j, Y .Note: Default is date format in WordPress settings if this value is blank.', 'cafe'),
        ]);

        $this->add_control('layout', [
            'label'         => __('Layout', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SELECT,
            'default'       => 'grid',
            'options' => [
                'grid'      => __( 'Grid', 'cafe' ),
                'carousel'   => __( 'Carousel', 'cafe' ),
            ],
        ]);

            //Grid
        $this->add_responsive_control('columns',[
            'label'         => __( 'Columns for row', 'cafe' ),
            'type'          => Controls_Manager::SLIDER,
            'range' => [
                'col' =>[
                    'min' => 1,
                    'max' => 6,
                ]
            ],
            'devices' => [ 'desktop', 'tablet', 'mobile' ],
            'desktop_default' => [
                'size' => 4,
                'unit' => 'col',
            ],
            'tablet_default' => [
                'size' => 3,
                'unit' => 'col',
            ],
            'mobile_default' => [
                'size' => 2,
                'unit' => 'col',
            ],
            'condition'     => [
                'layout' => 'grid',
            ],
            
        ]);
            //Slide
        $this->add_responsive_control('slides_to_show',[
            'label'         => __( 'Slides to Show', 'elementor' ),
            'type'          => Controls_Manager::SLIDER,
            'range' => [
                'px' =>[
                    'min' => 1,
                    'max' => 10,
                ]
            ],
            'devices' => [ 'desktop', 'tablet', 'mobile' ],
            'desktop_default' => [
                'size' => 4,
                'unit' => 'px',
            ],
            'tablet_default' => [
                'size' => 3,
                'unit' => 'px',
            ],
            'mobile_default' => [
                'size' => 2,
                'unit' => 'px',
            ],
            'condition'     => [
                'layout' => 'carousel',
            ],
            
        ]);

        $this->add_control('speed', [
            'label'         => __('Carousel: Speed to Scroll', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::NUMBER,
            'default'       => 5000,
            'condition'     => [
                'layout' => 'carousel',
            ],
        ]);
        $this->add_control('scroll', [
            'label'         => __('Carousel: Slide to Scroll', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::NUMBER,
            'default'       => 1,
            'condition'     => [
                'layout' => 'carousel',
            ],
        ]);
        $this->add_responsive_control('autoplay', [
            'label'         => __('Carousel: Auto Play', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
            'condition'     => [
                'layout' => 'carousel',
            ],
        ]);
        $this->add_responsive_control('show_pag', [
            'label'         => __('Carousel: Pagination', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
            'condition'     => [
                'layout' => 'carousel',
            ],
        ]);
        $this->add_responsive_control('show_nav', [
            'label'         => __('Carousel: Navigation', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SWITCHER,
            'label_on' => __( 'Show', 'cafe' ),
            'label_off' => __( 'Hide', 'cafe' ),
            'return_value' => 'true',
            'default' => 'true',
            'condition'     => [
                'layout' => 'carousel',
            ],
        ]);
        $this->add_control('nav_position', [
            'label'         => __('Carousel: Navigation position', 'cafe'),
            'description'   => __('', 'cafe'),
            'type'          => Controls_Manager::SELECT,
            'default'       => 'middle-nav',
            'options' => [
                'top-nav'  => __( 'Top', 'cafe' ),
                'middle-nav' => __( 'Middle', 'cafe' ),
            ],
            'condition'     => [
                'show_nav' => 'true',
                'layout' => 'carousel',
            ],
        ]);

        $this->end_controls_section();
        
    }
    /**
     * Load style
     */
    public function get_style_depends()
    {
        return ['cafe-style'];
    }

    /**
     * Retrieve the list of scripts the image carousel widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.3.0
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['jquery-slick', 'cafe-script'];
    }
    /**
     * Render
     */
    protected function render()
    {
        // default settings
        $settings = array_merge([ 
            'title'             => '',
            'username'          => '',
            'number'            => '',
            
            'img_size'          => 'large',
            'show_likes'        => '',
            'show_comments'     => '',
            'show_type'         => '',
            'show_time'         => '',
            'time_layout'       => 'elapsed',
            'date_format'       => '',
            'layout'            => 'carousel',
            'columns'           => '',

            'slides_to_show'    => 4,
            'speed'             => 5000,
            'scroll'            => 1,
            'autoplay'          => 'true',
            'show_pag'          => 'true',
            'show_nav'          => 'true',
            'nav_position'      => 'middle-nav',
            
        ], $this->get_settings_for_display());

        $this->add_inline_editing_attributes('title');

        $this->getViewTemplate('template', 'instagram', $settings);
    }
}

