<?php

namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;

/**
 * Clever Posts
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverPosts extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-posts';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Posts', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-blog';
    }

    /**
     * Register controls
     */
    protected function _register_controls()
    {
        $this->start_controls_section('content_settings', [
            'label' => __('Content Settings', 'cafe')
        ]);
        $this->add_control('cat', [
            'label' => __('Categories', 'cafe'),
            'type' => Controls_Manager::SELECT2,
            'default' => '',
            'multiple' => true,
            'description' => __('Select categories want display.', 'cafe'),
            'options' => $this->get_categories_for_cafe('category'),
        ]);
        $this->add_control('posts_per_page', [
            'label' => __('Number of items', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '3',
            'description' => __('Number post display.', 'cafe'),
        ]);
        $this->add_control('output_type', [
            'label' => __('Content display', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'excerpt',
            'options' => [
                'excerpt' => __('Excerpt', 'cafe'),
                'full' => __('Full Content', 'cafe'),
                'none' => __('None', 'cafe'),
            ],
            'description' => __('Number testimonial display.', 'cafe'),
        ]);
        $this->add_control('excerpt_length', [
            'label' => __('Excerpt Length', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '30',
            'condition' => [
                'output_type' => 'excerpt'
            ],
        ]);
        $this->add_control('pagination', [
            'label' => __('Pagination', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'none',
            'options' => [
                'none' => __('none', 'cafe'),
                'numeric' => __('Numeric', 'cafe'),
            ],
            'condition' => [
                'layout' => ['grid','list'],
            ],
            'description' => __('Not work with carousel layout. Numeric pagination work only with page have single widget posts. ', 'cafe'),
        ]);

        $this->end_controls_section();

        $this->start_controls_section('layout_settings', [
            'label' => __('Layout', 'cafe')
        ]);
        $this->add_control('layout', [
            'label' => __('Layout', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'grid',
            'options' => [
                'grid' => __('Grid', 'cafe'),
                'list' => __('List', 'cafe'),
                'carousel' => __('Carousel', 'cafe'),
            ],
            'description' => __('Layout of blog.', 'cafe'),
        ]);
        $this->add_control('style', [
            'label' => esc_html__('Style', 'cafe'),
            'type' =>  Controls_Manager::SELECT,
            'default' => 'default',
            'options' => [
                'default' => esc_html__('Default', 'cafe'),
                'basic' => esc_html__('Basic', 'cafe'),
                'boxed' => esc_html__('Boxed', 'cafe'),
                'image-shadow' => esc_html__('Image Shadow', 'cafe'),
                'img-left' => esc_html__('Image Left', 'cafe'),
                'first-large' => esc_html__('First Large (work ony with Grid)', 'cafe'),
                'content-overlay' => esc_html__('Content Overlay', 'cafe'),
            ],
            'condition' => [
                'layout' =>  ['carousel','grid']
            ],
        ]);
        $this->add_responsive_control('col', [
            'label' => __('Columns', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'desktop_default' => '3',
            'tablet_default' =>  '1',
            'mobile_default' => '1',
            'description' => __('Columns post display per row. With grid layout, min column is 1, max is 6. Unlimited with carousel.', 'cafe'),
            'condition' => [
                'layout' => 'grid'
            ],
        ]);
        $this->add_control('image_size', [
            'label' => __('Image size', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'medium',
            'options' => $this->getImgSizes(),
            'description' => __('Select image size fit to layout you want use.', 'cafe'),
        ]);
        $this->add_control('show_date_post', [
            'label' => __('Show date post', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('show_cat_post', [
            'label' => __('Show post categories', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('show_author_post', [
            'label' => __('Show author post', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('show_read_more', [
            'label' => __('Show read more', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_responsive_control('slides_to_show',[
            'label'         => __( 'Slides to Show', 'elementor' ),
            'type'          => Controls_Manager::SLIDER,
            'range' => [
                'px' =>[
                    'min' => 1,
                    'max' => 10,
                ]
            ],
            'devices' => [ 'desktop', 'tablet', 'mobile' ],
            'desktop_default' => [
                'size' => 4,
                'unit' => 'px',
            ],
            'tablet_default' => [
                'size' => 3,
                'unit' => 'px',
            ],
            'mobile_default' => [
                'size' => 2,
                'unit' => 'px',
            ],
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_control('scroll', [
            'label' => __('Slider to scroll', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '1',
            'description' => __('Number testimonial scroll per time.', 'cafe'),
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_responsive_control('show_nav', [
            'label' => __('Navigation', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_responsive_control('show_pag', [
            'label' => __('Pagination', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_responsive_control('autoplay', [
            'label' => __('Auto Play', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_control('speed', [
            'label' => __('Auto play speed', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '3000',
            'condition' => [
                'layout' => 'carousel',
                'autoplay' => 'true'
            ],
            'description' => __('Time(ms) to next slider.', 'cafe'),
        ]);
        $this->add_control('css_class', [
            'label' => __('Custom HTML Class', 'cafe'),
            'type' => Controls_Manager::TEXT,
            'description' => __('You may add a custom HTML class to style element later.', 'cafe'),
        ]);
        $this->end_controls_section();
    }

    /**
     * Load style
     */
    public function get_style_depends()
    {
        return ['cafe-style'];
    }

    /**
     * Retrieve the list of scripts the image carousel widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.3.0
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['jquery-slick', 'cafe-script'];
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
            'cat' => '',
            'posts_per_page' => '3',
            'output_type' => 'excerpt',
            'excerpt_length' => '30',
            'pagination' => 'none',
            'layout' => 'grid',
            'col' => '3',
            'col_table' => '1',
            'col_mobile' => '1',
            'image_size' => 'medium',
            'show_date_post' => 'false',
            'show_cat_post' => 'false',
            'show_author_post' => 'false',
            'show_read_more' => 'false',
            'show_nav' => 'false',
            'show_pag' => 'false',
            'show_avatar' => 'false',
            'autoplay' => 'false',
            'speed' => '3000',
            'css_class' => '',

        ], $this->get_settings_for_display());


        $this->getViewTemplate('template', 'posts', $settings);
    }
}