<?php namespace CleverAddonsForElementor\Widgets;

use Elementor\Repeater;
use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;

/**
 * CleverSlider
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverSlider extends CleverWidgetBase {
	public function get_name() {
		return 'clever-slider';
	}

	public function get_title() {
		return __( 'Clever Slider', 'cafe' );
	}

	public function get_icon() {
		return 'cs-font clever-icon-slider';
	}

	public function get_keywords() {
		return [ 'slides', 'slider' ];
	}

	public function get_style_depends() {
		return [ 'cleverfont' ];
	}

	public function get_script_depends() {
		return [ 'imagesloaded', 'jquery-slick' ];
	}

	public static function get_button_sizes() {
		return [
			'xs' => __( 'Extra Small', 'cafe' ),
			'sm' => __( 'Small', 'cafe' ),
			'md' => __( 'Medium', 'cafe' ),
			'lg' => __( 'Large', 'cafe' ),
			'xl' => __( 'Extra Large', 'cafe' ),
		];
	}

	protected function _register_controls() {
		$repeater = new Repeater();

		$this->start_controls_section( 'section_slides', [
			'label' => __( 'Slides', 'cafe' ),
		] );

		$repeater->start_controls_tabs( 'slides_repeater' );

		$repeater->start_controls_tab( 'background', [ 'label' => __( 'Background', 'cafe' ) ] );

		$repeater->add_control( 'background_color', [
			'label'     => __( 'Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '#bbbbbb',
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}}' => 'background-color: {{VALUE}}',
			],
		] );

		$repeater->add_control( 'background_image', [
			'label'     => _x( 'Image', 'Background Control', 'cafe' ),
			'type'      => Controls_Manager::MEDIA,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-bg' => 'background-image: url({{URL}})',
			],
		] );
		$repeater->add_control( 'background_video', [
			'label'      => __( 'Video url', 'cafe' ),
			'description'      => __( 'Support Video and Youtube only.', 'cafe' ),
			'placeholder'      => __( 'https://www.youtube.com/watch?v=xxxx', 'cafe' ),
			'type'       => Controls_Manager::TEXT,
			'default'    => '',
			'input_type'=>'url',
			'separator'  => 'before',
		] );
		$repeater->add_control( 'background_video_sound', [
			'label'      => __( 'Enable Sound', 'cafe' ),
			'type'       => Controls_Manager::SWITCHER,
			'default'    => '',
			'separator'  => 'before',
			'conditions' => [
				'terms' => [
					[
						'name'     => 'background_video',
						'operator' => '!=',
						'value'    => '',
					],
				],
			],
		] );
		$repeater->add_control( 'background_size', [
			'label'      => _x( 'Size', 'Background Control', 'cafe' ),
			'type'       => Controls_Manager::SELECT,
			'default'    => 'cover',
			'options'    => [
				'cover'   => _x( 'Cover', 'Background Control', 'cafe' ),
				'contain' => _x( 'Contain', 'Background Control', 'cafe' ),
				'auto'    => _x( 'Auto', 'Background Control', 'cafe' ),
			],
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-bg' => 'background-size: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'     => 'background_image[url]',
						'operator' => '!=',
						'value'    => '',
					],
				],
			],
		] );

		$repeater->add_control( 'background_ken_burns', [
			'label'      => __( 'Ken Burns Effect', 'cafe' ),
			'type'       => Controls_Manager::SWITCHER,
			'default'    => '',
			'separator'  => 'before',
			'conditions' => [
				'terms' => [
					[
						'name'     => 'background_image[url]',
						'operator' => '!=',
						'value'    => '',
					],
				],
			],
		] );

		$repeater->add_control( 'zoom_direction', [
			'label'      => __( 'Zoom Direction', 'cafe' ),
			'type'       => Controls_Manager::SELECT,
			'default'    => 'in',
			'options'    => [
				'in'  => __( 'In', 'cafe' ),
				'out' => __( 'Out', 'cafe' ),
			],
			'conditions' => [
				'terms' => [
					[
						'name'     => 'background_ken_burns',
						'operator' => '!=',
						'value'    => '',
					],
				],
			],
		] );

		$repeater->add_control( 'background_overlay', [
			'label'      => __( 'Background Overlay', 'cafe' ),
			'type'       => Controls_Manager::SWITCHER,
			'default'    => 'yes',
			'separator'  => 'before',
			'conditions' => [
				'terms' => [
					[
						'name'     => 'background_image[url]',
						'operator' => '!=',
						'value'    => '',
					],
				],
			],
		] );

		$repeater->add_control( 'background_overlay_color', [
			'label'      => __( 'Color', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'default'    => '',
			'conditions' => [
				'terms' => [
					[
						'name'  => 'background_overlay',
						'value' => 'yes',
					],
				],
			],
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-bg-overlay' => 'background-color: {{VALUE}}',
			],
		] );

		$repeater->add_control( 'background_overlay_blend_mode', [
			'label'      => __( 'Blend Mode', 'cafe' ),
			'type'       => Controls_Manager::SELECT,
			'options'    => [
				''            => __( 'Normal', 'cafe' ),
				'multiply'    => 'Multiply',
				'screen'      => 'Screen',
				'overlay'     => 'Overlay',
				'darken'      => 'Darken',
				'lighten'     => 'Lighten',
				'color-dodge' => 'Color Dodge',
				'color-burn'  => 'Color Burn',
				'hue'         => 'Hue',
				'saturation'  => 'Saturation',
				'color'       => 'Color',
				'exclusion'   => 'Exclusion',
				'luminosity'  => 'Luminosity',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'background_overlay',
						'value' => 'yes',
					],
				],
			],
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-bg-overlay' => 'mix-blend-mode: {{VALUE}}',
			],
		] );
		$repeater->add_control( 'background_animation', [
			'label'      => __( 'Background Animation', 'cafe' ),
			'type'       => Controls_Manager::SELECT,
			'default'    => 'inherit',
			'separator'  => 'before',
			'conditions' => [
				'terms' => [
					[
						'name'     => 'background_ken_burns',
						'operator' => '==',
						'value'    => '',
					],
				],
			],
			'options'    => [
				'inherit'           => __( 'Inherit', 'cafe' ),
				'bounce'            => __( 'Bounce', 'cafe' ),
				'bounceIn'          => __( 'Bounce In', 'cafe' ),
				'bounceInDown'      => __( 'Bounce In Down', 'cafe' ),
				'bounceInLeft'      => __( 'Bounce In Left', 'cafe' ),
				'bounceInRight'     => __( 'Bounce In Right', 'cafe' ),
				'bounceInUp'        => __( 'Bounce In Up', 'cafe' ),
				'fadeIn'            => __( 'Fade In', 'cafe' ),
				'fadeInDown'        => __( 'Fade In Down', 'cafe' ),
				'fadeInLeft'        => __( 'Fade In Left', 'cafe' ),
				'fadeInRight'       => __( 'Fade In Right', 'cafe' ),
				'fadeInUp'          => __( 'Fade In Up', 'cafe' ),
				'flash'             => __( 'Flash', 'cafe' ),
				'headShake'         => __( 'Head Shake', 'cafe' ),
				'lightSpeedIn'      => __( 'Light Speed In', 'cafe' ),
				'jello'             => __( 'Jello', 'cafe' ),
				'pulse'             => __( 'Pulse', 'cafe' ),
				'rotateIn'          => __( 'Rotate In', 'cafe' ),
				'rotateInDownLeft'  => __( 'Rotate Down Left', 'cafe' ),
				'rotateInDownRight' => __( 'Rotate Down Right', 'cafe' ),
				'rotateInUpLeft'    => __( 'Rotate Up Left', 'cafe' ),
				'rotateInUpRight'   => __( 'Rotate Up Right', 'cafe' ),
				'rollIn'            => __( 'Roll In', 'cafe' ),
				'zoomIn'            => __( 'Zoom In', 'cafe' ),
				'rubberBand'        => __( 'Rubber Band', 'cafe' ),
				'shake'             => __( 'Shake', 'cafe' ),
				'swing'             => __( 'Swing', 'cafe' ),
				'slideInDown'       => __( 'Slide In Down', 'cafe' ),
				'slideInLeft'       => __( 'Slide In Left', 'cafe' ),
				'slideInRight'      => __( 'Slide In Right', 'cafe' ),
				'slideInUp'         => __( 'Slide In Up', 'cafe' ),
				'tada'              => __( 'Tada', 'cafe' ),
				'wobble'            => __( 'Wobble', 'cafe' ),
				'zoomInDown'        => __( 'Zoom In Down', 'cafe' ),
				'zoomInLeft'        => __( 'Zoom In Left', 'cafe' ),
				'zoomInRight'       => __( 'Zoom In Right', 'cafe' ),
				'zoomInUp'          => __( 'Zoom In Up', 'cafe' )
			],
		] );
		$repeater->add_control( 'background_transition_duration', [
			'label'     => __( 'Transition Duration(ms)', 'cafe' ),
			'type'      => Controls_Manager::NUMBER,
			'default'   => 1000,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-bg' => 'animation-duration: {{VALUE}}ms; transition-duration: {{VALUE}}ms',
			],
		] );
		$repeater->end_controls_tab();

		$repeater->start_controls_tab( 'content', [ 'label' => __( 'Content', 'cafe' ) ] );

		$repeater->add_control( 'heading', [
			'label'       => __( 'Title & Description', 'cafe' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Slide Heading', 'cafe' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'description', [
			'label'      => __( 'Description', 'cafe' ),
			'type'       => Controls_Manager::TEXTAREA,
			'default'    => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'cafe' ),
			'show_label' => false,
		] );

		$repeater->add_control( 'button_text', [
			'label'   => __( 'Button Text', 'cafe' ),
			'type'    => Controls_Manager::TEXT,
			'default' => __( 'Click Here', 'cafe' ),
		] );
		$repeater->add_control( 'button_style', [
			'label'   => __( 'Button style', 'cafe' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'normal',
			'options' => [
				'normal'    => __( 'Normal', 'cafe' ),
				'underline' => __( 'Underline', 'cafe' ),
				'outline'   => __( 'Outline', 'cafe' ),
			]
		] );
		$repeater->add_control( 'link', [
			'label'       => __( 'Link', 'cafe' ),
			'type'        => Controls_Manager::URL,
			'placeholder' => __( 'https://yoursite.com', 'cafe' ),
		] );

		$repeater->add_control( 'link_click', [
			'label'      => __( 'Apply Link On', 'cafe' ),
			'type'       => Controls_Manager::SELECT,
			'options'    => [
				'slide'  => __( 'Whole Slide', 'cafe' ),
				'button' => __( 'Button Only', 'cafe' ),
			],
			'default'    => 'slide',
			'conditions' => [
				'terms' => [
					[
						'name'     => 'link[url]',
						'operator' => '!=',
						'value'    => '',
					],
				],
			],
		] );
		$repeater->add_control( 'content_animation', [
			'label'     => __( 'Content Animation', 'cafe' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'inherit',
			'separator' => 'before',
			'options'   => [
				'inherit'           => __( 'Inherit', 'cafe' ),
				'bounce'            => __( 'Bounce', 'cafe' ),
				'bounceIn'          => __( 'Bounce In', 'cafe' ),
				'bounceInDown'      => __( 'Bounce In Down', 'cafe' ),
				'bounceInLeft'      => __( 'Bounce In Left', 'cafe' ),
				'bounceInRight'     => __( 'Bounce In Right', 'cafe' ),
				'bounceInUp'        => __( 'Bounce In Up', 'cafe' ),
				'fadeIn'            => __( 'Fade In', 'cafe' ),
				'fadeInDown'        => __( 'Fade In Down', 'cafe' ),
				'fadeInLeft'        => __( 'Fade In Left', 'cafe' ),
				'fadeInRight'       => __( 'Fade In Right', 'cafe' ),
				'fadeInUp'          => __( 'Fade In Up', 'cafe' ),
				'flash'             => __( 'Flash', 'cafe' ),
				'headShake'         => __( 'Head Shake', 'cafe' ),
				'lightSpeedIn'      => __( 'Light Speed In', 'cafe' ),
				'jello'             => __( 'Jello', 'cafe' ),
				'pulse'             => __( 'Pulse', 'cafe' ),
				'rotateIn'          => __( 'Rotate In', 'cafe' ),
				'rotateInDownLeft'  => __( 'Rotate Down Left', 'cafe' ),
				'rotateInDownRight' => __( 'Rotate Down Right', 'cafe' ),
				'rotateInUpLeft'    => __( 'Rotate Up Left', 'cafe' ),
				'rotateInUpRight'   => __( 'Rotate Up Right', 'cafe' ),
				'rollIn'            => __( 'Roll In', 'cafe' ),
				'zoomIn'            => __( 'Zoom In', 'cafe' ),
				'rubberBand'        => __( 'Rubber Band', 'cafe' ),
				'shake'             => __( 'Shake', 'cafe' ),
				'swing'             => __( 'Swing', 'cafe' ),
				'slideInDown'       => __( 'Slide In Down', 'cafe' ),
				'slideInLeft'       => __( 'Slide In Left', 'cafe' ),
				'slideInRight'      => __( 'Slide In Right', 'cafe' ),
				'slideInUp'         => __( 'Slide In Up', 'cafe' ),
				'tada'              => __( 'Tada', 'cafe' ),
				'wobble'            => __( 'Wobble', 'cafe' ),
				'zoomInDown'        => __( 'Zoom In Down', 'cafe' ),
				'zoomInLeft'        => __( 'Zoom In Left', 'cafe' ),
				'zoomInRight'       => __( 'Zoom In Right', 'cafe' ),
				'zoomInUp'          => __( 'Zoom In Up', 'cafe' )
			],
		] );
		$repeater->add_control( 'content_transition_duration', [
			'label'     => __( 'Transition Duration(ms)', 'cafe' ),
			'type'      => Controls_Manager::NUMBER,
			'default'   => 500,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-content' => 'animation-duration: calc({{VALUE}}ms); transition-duration: calc({{VALUE}}ms)',
			],
		] );
		$repeater->end_controls_tab();

		$repeater->start_controls_tab( 'style', [ 'label' => __( 'Style', 'cafe' ) ] );

		$repeater->add_control( 'custom_style', [
			'label'       => __( 'Custom', 'cafe' ),
			'type'        => Controls_Manager::SWITCHER,
			'description' => __( 'Set custom style that will only affect this specific slide.', 'cafe' ),
		] );

		$repeater->add_responsive_control( 'content_max_width', [
			'label'          => __( 'Content Width', 'cafe' ),
			'type'           => Controls_Manager::SLIDER,
			'range'          => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				],
				'%'  => [
					'min' => 0,
					'max' => 100,
				],
			],
			'size_units'     => [ '%', 'px' ],
			'default'        => [
				'size' => '100',
				'unit' => '%',
			],
			'tablet_default' => [
				'unit' => '%',
			],
			'mobile_default' => [
				'unit' => '%',
			],
			'selectors'      => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-content' => 'width: {{SIZE}}{{UNIT}};',
			],
			'conditions'     => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );

		$repeater->add_responsive_control( 'slides_padding', [
			'label'      => __( 'Padding', 'cafe' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );
		$repeater->add_control(
			'align_divider',
			[
				'type'       => Controls_Manager::DIVIDER,
				'style'      => 'thick',
				'conditions' => [
					'terms' => [
						[
							'name'  => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_responsive_control( 'horizontal_position', [
			'label'                => __( 'Horizontal Position', 'cafe' ),
			'type'                 => Controls_Manager::CHOOSE,
			'label_block'          => false,
			'options'              => [
				'left'   => [
					'title' => __( 'Left', 'cafe' ),
					'icon'  => 'eicon-h-align-left',
				],
				'center' => [
					'title' => __( 'Center', 'cafe' ),
					'icon'  => 'eicon-h-align-center',
				],
				'right'  => [
					'title' => __( 'Right', 'cafe' ),
					'icon'  => 'eicon-h-align-right',
				],
			],
			'selectors'            => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-content' => '{{VALUE}}',
			],
			'selectors_dictionary' => [
				'left'   => 'margin-right: auto',
				'center' => 'margin: 0 auto',
				'right'  => 'margin-left: auto',
			],
			'conditions'           => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );

		$repeater->add_responsive_control( 'vertical_position', [
			'label'                => __( 'Vertical Position', 'cafe' ),
			'type'                 => Controls_Manager::CHOOSE,
			'label_block'          => false,
			'options'              => [
				'top'    => [
					'title' => __( 'Top', 'cafe' ),
					'icon'  => 'eicon-v-align-top',
				],
				'middle' => [
					'title' => __( 'Middle', 'cafe' ),
					'icon'  => 'eicon-v-align-middle',
				],
				'bottom' => [
					'title' => __( 'Bottom', 'cafe' ),
					'icon'  => 'eicon-v-align-bottom',
				],
			],
			'selectors'            => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner' => 'align-items: {{VALUE}}',
			],
			'selectors_dictionary' => [
				'top'    => 'flex-start',
				'middle' => 'center',
				'bottom' => 'flex-end',
			],
			'conditions'           => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );

		$repeater->add_responsive_control( 'text_align', [
			'label'       => __( 'Text Align', 'cafe' ),
			'type'        => Controls_Manager::CHOOSE,
			'label_block' => false,
			'options'     => [
				'left'   => [
					'title' => __( 'Left', 'cafe' ),
					'icon'  => 'fa fa-align-left',
				],
				'center' => [
					'title' => __( 'Center', 'cafe' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'  => [
					'title' => __( 'Right', 'cafe' ),
					'icon'  => 'fa fa-align-right',
				],
			],
			'selectors'   => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .slick-slide-inner' => 'text-align: {{VALUE}}',
			],
			'conditions'  => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control(
			'color_divider',
			[
				'type'       => Controls_Manager::DIVIDER,
				'style'      => 'thick',
				'conditions' => [
					'terms' => [
						[
							'name'  => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_control( 'heading_color', [
			'label'      => __( 'Heading Color', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-heading' => 'color: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );

		$repeater->add_control( 'des_color', [
			'label'      => __( 'Description Color', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-desc' => 'color: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control(
			'button_divider',
			[
				'type'       => Controls_Manager::DIVIDER,
				'style'      => 'thick',
				'conditions' => [
					'terms' => [
						[
							'name'  => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_control( 'button_heading', [
			'label'      => __( 'Button', 'cafe' ),
			'type'       => Controls_Manager::HEADING,
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control( 'button_color', [
			'label'      => __( 'Color', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-btn' => 'color: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control( 'button_bg', [
			'label'      => __( 'Background', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-btn.outline::after,{{WRAPPER}} {{CURRENT_ITEM}}  .cafe-slide-btn.normal::after' => 'background: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control(
			'button_hover_divider',
			[
				'type'       => Controls_Manager::DIVIDER,
				'style'      => 'thick',
				'conditions' => [
					'terms' => [
						[
							'name'  => 'custom_style',
							'value' => 'yes',
						],
					],
				],
			]
		);
		$repeater->add_control( 'button_hover_heading', [
			'label'      => __( 'Button Hover', 'cafe' ),
			'type'       => Controls_Manager::HEADING,
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control( 'button_color_hover', [
			'label'      => __( 'Color', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-btn:hover' => 'color: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->add_control( 'button_bg_hover', [
			'label'      => __( 'Background', 'cafe' ),
			'type'       => Controls_Manager::COLOR,
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .cafe-slide-btn.outline:hover:after,{{WRAPPER}} {{CURRENT_ITEM}}  .cafe-slide-btn.normal:hover:after' => 'background: {{VALUE}}',
			],
			'conditions' => [
				'terms' => [
					[
						'name'  => 'custom_style',
						'value' => 'yes',
					],
				],
			],
		] );
		$repeater->end_controls_tab();

		$repeater->end_controls_tabs();

		$this->add_control( 'slides', [
			'label'       => __( 'Slides', 'cafe' ),
			'type'        => Controls_Manager::REPEATER,
			'show_label'  => true,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'heading'          => __( 'Slide 1', 'cafe' ),
					'description'      => __( 'Lorem ipsum dolor sit amet consectetur adipiscing elit dolor', 'cafe' ),
					'button_text'      => __( 'Click Here', 'cafe' ),
					'background_color' => '#3d70b2',
				],
				[
					'heading'          => __( 'Slide 2', 'cafe' ),
					'description'      => __( 'Lorem ipsum dolor sit amet consectetur adipiscing elit dolor', 'cafe' ),
					'button_text'      => __( 'Click Here', 'cafe' ),
					'background_color' => '#6596e6',
				],
				[
					'heading'          => __( 'Slide 3', 'cafe' ),
					'description'      => __( 'Lorem ipsum dolor sit amet consectetur adipiscing elit dolor', 'cafe' ),
					'button_text'      => __( 'Click Here', 'cafe' ),
					'background_color' => '#41d6c3',
				],
			],
			'title_field' => '{{{ heading }}}',
		] );

		$this->add_responsive_control( 'slides_height', [
			'label'      => __( 'Height', 'cafe' ),
			'type'       => Controls_Manager::SLIDER,
			'range'      => [
				'px' => [
					'min' => 100,
					'max' => 1000,
				],
				'vh' => [
					'min' => 10,
					'max' => 100,
				],
			],
			'default'    => [
				'size' => 400,
			],
			'size_units' => [ 'px', 'vh'],
			'selectors'  => [
				'{{WRAPPER}} .slick-slide' => 'height: {{SIZE}}{{UNIT}};',
			],
			'separator'  => 'before',
		] );
		$this->add_responsive_control( 'slides_width', [
			'label'      => __( 'Container width', 'cafe' ),
			'type'       => Controls_Manager::SLIDER,
			'range'      => [
				'px' => [
					'min' => 100,
					'max' => 2000,
				],
				'vw' => [
					'min' => 10,
					'max' => 100,
				],'%' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'default'    => [
				'size' => 1400,
			],
			'size_units' => [ 'px', 'vw','%' ],
			'selectors'  => [
				'{{WRAPPER}} .slick-slide-inner' => 'width: {{SIZE}}{{UNIT}};',
			]
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'section_slider_options', [
			'label' => __( 'Slider Settings', 'cafe' ),
			'type'  => Controls_Manager::SECTION,
		] );
		$this->add_responsive_control( 'show_arrows', [
			'label'          => __( 'Show Arrows', 'cafe' ),
			'type'           => Controls_Manager::SWITCHER,
			'default'        => 'yes',
			'tablet_default' => 'yes',
			'mobile_default' => 'no'
		] );
		$this->add_responsive_control( 'show_dots', [
			'label'   => __( 'Show Dots', 'cafe' ),
			'type'    => Controls_Manager::SWITCHER,
			'default' => 'yes',
		] );
		$this->add_control( 'pause_on_hover', [
			'label'   => __( 'Pause on Hover', 'cafe' ),
			'type'    => Controls_Manager::SWITCHER,
			'default' => 'yes',
		] );

		$this->add_control( 'autoplay', [
			'label'   => __( 'Autoplay', 'cafe' ),
			'type'    => Controls_Manager::SWITCHER,
			'default' => 'yes',
		] );

		$this->add_control( 'autoplay_speed', [
			'label'     => __( 'Autoplay Speed', 'cafe' ),
			'type'      => Controls_Manager::NUMBER,
			'default'   => 5000,
			'condition' => [
				'autoplay' => 'yes',
			],
			'selectors' => [
				'{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
			],
		] );

		$this->add_control( 'infinite', [
			'label'   => __( 'Infinite Loop', 'cafe' ),
			'type'    => Controls_Manager::SWITCHER,
			'default' => 'yes',
		] );

		$this->add_control( 'transition', [
			'label'   => __( 'Slide Effect', 'cafe' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'slide',
			'options' => [
				'slide' => __( 'Slide', 'cafe' ),
				'fade'  => __( 'Fade', 'cafe' ),
			],
		] );

		$this->add_control( 'transition_speed', [
			'label'   => __( 'Transition Speed (ms)', 'cafe' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 500,
		] );

		$this->add_control( 'content_animation', [
			'label'   => __( 'Content Animation', 'cafe' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'fadeInUp',
			'options' => [
				''                  => __( 'None', 'cafe' ),
				'bounce'            => __( 'Bounce', 'cafe' ),
				'bounceIn'          => __( 'Bounce In', 'cafe' ),
				'bounceInDown'      => __( 'Bounce In Down', 'cafe' ),
				'bounceInLeft'      => __( 'Bounce In Left', 'cafe' ),
				'bounceInRight'     => __( 'Bounce In Right', 'cafe' ),
				'bounceInUp'        => __( 'Bounce In Up', 'cafe' ),
				'fadeIn'            => __( 'Fade In', 'cafe' ),
				'fadeInDown'        => __( 'Fade In Down', 'cafe' ),
				'fadeInLeft'        => __( 'Fade In Left', 'cafe' ),
				'fadeInRight'       => __( 'Fade In Right', 'cafe' ),
				'fadeInUp'          => __( 'Fade In Up', 'cafe' ),
				'flash'             => __( 'Flash', 'cafe' ),
				'headShake'         => __( 'Head Shake', 'cafe' ),
				'lightSpeedIn'      => __( 'Light Speed In', 'cafe' ),
				'jello'             => __( 'Jello', 'cafe' ),
				'pulse'             => __( 'Pulse', 'cafe' ),
				'rotateIn'          => __( 'Rotate In', 'cafe' ),
				'rotateInDownLeft'  => __( 'Rotate Down Left', 'cafe' ),
				'rotateInDownRight' => __( 'Rotate Down Right', 'cafe' ),
				'rotateInUpLeft'    => __( 'Rotate Up Left', 'cafe' ),
				'rotateInUpRight'   => __( 'Rotate Up Right', 'cafe' ),
				'rollIn'            => __( 'Roll In', 'cafe' ),
				'zoomIn'            => __( 'Zoom In', 'cafe' ),
				'rubberBand'        => __( 'Rubber Band', 'cafe' ),
				'shake'             => __( 'Shake', 'cafe' ),
				'swing'             => __( 'Swing', 'cafe' ),
				'slideInDown'       => __( 'Slide In Down', 'cafe' ),
				'slideInLeft'       => __( 'Slide In Left', 'cafe' ),
				'slideInRight'      => __( 'Slide In Right', 'cafe' ),
				'slideInUp'         => __( 'Slide In Up', 'cafe' ),
				'tada'              => __( 'Tada', 'cafe' ),
				'wobble'            => __( 'Wobble', 'cafe' ),
				'zoomInDown'        => __( 'Zoom In Down', 'cafe' ),
				'zoomInLeft'        => __( 'Zoom In Left', 'cafe' ),
				'zoomInRight'       => __( 'Zoom In Right', 'cafe' ),
				'zoomInUp'          => __( 'Zoom In Up', 'cafe' )
			],
		] );

		$this->end_controls_section();
		$this->start_controls_section( 'section_style_title', [
			'label' => __( 'Title', 'cafe' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'heading_spacing', [
			'label'     => __( 'Spacing', 'cafe' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .slick-slide-inner .cafe-slide-heading:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_control( 'heading_color', [
			'label'     => __( 'Text Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-heading' => 'color: {{VALUE}}',

			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'heading_typography',
			'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
			'selector' => '{{WRAPPER}} .cafe-slide-heading',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'section_style_description', [
			'label' => __( 'Description', 'cafe' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_responsive_control( 'description_spacing', [
			'label'     => __( 'Spacing', 'cafe' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .slick-slide-inner .cafe-slide-desc:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}}',
			],
		] );

		$this->add_control( 'description_color', [
			'label'     => __( 'Text Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-desc' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'description_typography',
			'scheme'   => Scheme_Typography::TYPOGRAPHY_2,
			'selector' => '{{WRAPPER}} .cafe-slide-desc',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'section_style_button', [
			'label' => __( 'Button', 'cafe' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'button_size', [
			'label'   => __( 'Size', 'cafe' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'sm',
			'options' => self::get_button_sizes(),
		] );


		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'button_typography',
			'selector' => '{{WRAPPER}} .cafe-slide-btn',
			'scheme'   => Scheme_Typography::TYPOGRAPHY_4,
		] );

		$this->add_control( 'button_border_width', [
			'label'     => __( 'Border Width', 'cafe' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 20,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn.normal::before, {{WRAPPER}} .cafe-slide-btn.outline::before' => 'border-width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'button_border_radius', [
			'label'     => __( 'Border Radius', 'cafe' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn' => 'border-radius: {{SIZE}}{{UNIT}};',
			],
		] );
        $this->add_responsive_control( 'button_padding', [
            'label'      => __( 'Padding', 'cafe' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em'],
            'selectors'  => [
                '{{WRAPPER}} .cafe-slide-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'separator' => 'after',
        ] );
		$this->start_controls_tabs( 'button_tabs' );

		$this->start_controls_tab( 'normal', [ 'label' => __( 'Normal', 'cafe' ) ] );

		$this->add_control( 'button_text_color', [
			'label'     => __( 'Text Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'button_background_color', [
			'label'     => __( 'Background Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn.normal::after, {{WRAPPER}} .cafe-slide-btn.outline::after' => 'background-color: {{VALUE}};',
			],
		] );

		$this->add_control( 'button_border_color', [
			'label'     => __( 'Border Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn.normal::before, {{WRAPPER}} .cafe-slide-btn.outline::before' => 'border-color: {{VALUE}};',
			],
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'hover', [ 'label' => __( 'Hover', 'cafe' ) ] );

		$this->add_control( 'button_hover_text_color', [
			'label'     => __( 'Text Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn:hover' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'button_hover_background_color', [
			'label'     => __( 'Background Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn.normal:hover:after, {{WRAPPER}} .cafe-slide-btn.outline:hover:after' => 'background-color: {{VALUE}};',
			],
		] );

		$this->add_control( 'button_hover_border_color', [
			'label'     => __( 'Border Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slide-btn.normal:hover:before, {{WRAPPER}} .cafe-slide-btn.outline:hover:before' => 'border-color: {{VALUE}};',
			],
		] );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		$this->start_controls_section( 'section_style_navigation', [
			'label' => __( 'Navigation', 'cafe' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'heading_style_arrows', [
			'label'     => __( 'Arrows', 'cafe' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );
		$this->add_control( 'arrow_left_icon', [
			'label'     => __( 'Arrow Left', 'cafe' ),
			'type'      => 'clevericon',
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );
		$this->add_control( 'arrow_right_icon', [
			'label'     => __( 'Arrow Right', 'cafe' ),
			'type'      => 'clevericon',
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );
		$this->add_control( 'arrows_position', [
			'label'     => __( 'Arrows Position', 'cafe' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'inside',
			'options'   => [
				'inside'  => __( 'Inside', 'cafe' ),
				'outside' => __( 'Outside', 'cafe' ),
			],
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );

		$this->add_control( 'arrows_size', [
			'label'     => __( 'Arrows Size', 'cafe' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 20,
					'max' => 60,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .cafe-slider-wrapper .slick-slider .slick-prev:before, {{WRAPPER}} .cafe-slider-wrapper .slick-slider .slick-next:before' => 'font-size: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );

		$this->add_control( 'arrows_color', [
			'label'     => __( 'Arrows Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slider-wrapper .slick-arrow:before' => 'color: {{VALUE}};',
			],
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );
		$this->add_control( 'arrows_color_hover', [
			'label'     => __( 'Arrows Color Hover', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slider-wrapper .slick-arrow:hover:before' => 'color: {{VALUE}};',
			],
			'condition' => [
				'show_arrows' => 'yes',
			],
		] );

		$this->add_control( 'heading_style_dots', [
			'label'     => __( 'Dots', 'cafe' ),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
			'condition' => [
				'show_dots' => 'yes',
			],
		] );

		$this->add_control( 'dots_style', [
			'label'     => __( 'Dots Style', 'cafe' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'dots',
			'options'   => [
				'dots'  => __( 'Dots', 'cafe' ),
				'line'  => __( 'Line', 'cafe' ),
				'group' => __( 'Group', 'cafe' ),
			],
			'condition' => [
				'show_dots' => 'yes',
			],
		] );

		$this->add_control( 'dots_position', [
			'label'     => __( 'Dots Position', 'cafe' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'inside',
			'options'   => [
				'outside' => __( 'Outside', 'cafe' ),
				'inside'  => __( 'Inside', 'cafe' ),
			],
			'condition' => [
				'show_dots' => 'yes',
			],
		] );

		$this->add_control( 'dots_size', [
			'label'     => __( 'Dots Size', 'cafe' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 5,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides .slick-dots li button'  => 'width: {{SIZE}}{{UNIT}}, height: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides .slick-group li button' => 'width: {{SIZE}}{{UNIT}}, height: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides > ul.slick-line button' => 'width: {{SIZE}}{{UNIT}};',
			],
			'condition' => [
				'show_dots' => 'yes',
			],
		] );

		$this->add_control( 'dots_color', [
			'label'     => __( 'Dots Color', 'cafe' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides > ul.slick-group li.slick-active button, {{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides > ul.slick-group li:hover button'=> 'color: {{VALUE}};background-color: {{VALUE}}',
				'{{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides .slick-dots li button, {{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides .slick-line li button'                      => 'background-color: {{VALUE}}',
				'{{WRAPPER}} .cafe-slider-wrapper .cafe-slider-slides .slick-group li button'                                                                                                 => 'color: {{VALUE}}',
				],
			'condition' => [
				'show_dots' => 'yes',
			],
		] );

		$this->end_controls_section();
        $this->start_controls_section( 'section_style_background', [
            'label' => __( 'Background Overlay', 'cafe' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );
        $this->add_group_control( Group_Control_Background ::get_type(), [
            'name'     => 'bg_overlay_style',
            'selector' => '{{WRAPPER}} .cafe-slide-bg-overlay',
        ] );
        $this->add_control( 'bg_overlay_blend_mode_style', [
            'label'      => __( 'Blend Mode', 'cafe' ),
            'type'       => Controls_Manager::SELECT,
            'options'    => [
                ''            => __( 'Normal', 'cafe' ),
                'multiply'    => 'Multiply',
                'screen'      => 'Screen',
                'overlay'     => 'Overlay',
                'darken'      => 'Darken',
                'lighten'     => 'Lighten',
                'color-dodge' => 'Color Dodge',
                'color-burn'  => 'Color Burn',
                'hue'         => 'Hue',
                'saturation'  => 'Saturation',
                'color'       => 'Color',
                'exclusion'   => 'Exclusion',
                'luminosity'  => 'Luminosity',
            ],
            'selectors'  => [
                '{{WRAPPER}} .cafe-slide-bg-overlay' => 'mix-blend-mode: {{VALUE}}',
            ],
        ] );
        $this->end_controls_section();
	}

	/**
	 * Render
	 */
	protected function render() {
		$this->getViewTemplate( 'template', 'slider', $this->get_settings() );
	}
}
