<?php

namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

/**
 * Clever Testimonial
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverTestimonial extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-testimonial';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Testimonial', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-quote-1';
    }

    /**
     * Register controls
     */
    protected function _register_controls()
    {

        $repeater = new \Elementor\Repeater();
        $repeater->add_control('author_avatar', [
            'label' => __('Avatar', 'cafe'),
            'type' => Controls_Manager::MEDIA,
        ]);
        $repeater->add_control(
            'author',
            [
                'label' => __('Author', 'cafe'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'author_des',
            [
                'label' => __('Author Description', 'cafe'),
                'type' => Controls_Manager::TEXT,
            ]
        );
        $repeater->add_control('star', [
            'label' => __('Star', 'elementor'),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 1,
                    'max' => 5,
                ]
            ],

        ]);
        $repeater->add_control(
            'testimonial_content',
            [
                'label' => __('Testimonial Content', 'cafe'),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->start_controls_section('content_settings', [
            'label' => __('Content Settings', 'cafe')
        ]);
        $this->add_control('content', [
            'label' => __('Content', 'cafe'),
            'type' => Controls_Manager::REPEATER,
            'fields' => $repeater->get_controls(),
            'title_field' => '{{{ author }}}',
            'default' => [
                [
                    'author' => __('Testimonial 1', 'cafe'),
                ],
                [
                    'author' => __('Testimonial 2', 'cafe'),
                ],
                [
                    'author' => __('Testimonial 3', 'cafe'),
                ],
            ],

        ]);
        $this->end_controls_section();
        $this->start_controls_section('layout_settings', [
            'label' => __('Layout Settings', 'cafe')
        ]);
        $this->add_control('show_quotation', [
            'label' => __('Enable Quotation icon', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('layout', [
            'label' => __('Layout', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'grid',
            'options' => [
                'grid' => __('Grid', 'cafe'),
                'carousel' => __('Carousel', 'cafe'),
            ],
            'description' => __('Layout of testimonial.', 'cafe'),
        ]);
        $this->add_control('style', [
            'label' => __('Style', 'cafe'),
            'type' => Controls_Manager::SELECT,
            'default' => 'default',
            'options' => [
                'default' => __('Default', 'cafe'),
                'style-1' => __('Style 1', 'cafe'),
                'style-2' => __('Style 2', 'cafe'),
                'style-3' => __('Style 3', 'cafe'),
            ],
            'description' => __('style of testimonial.', 'cafe'),
        ]);
        $this->add_responsive_control('columns', [
            'label' => __('Columns For Row', 'elementor'),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 1,
                    'max' => 6,
                ]
            ],
            'devices' => ['desktop', 'tablet', 'mobile'],
            'desktop_default' => [
                'size' => 1,
                'unit' => 'px',
            ],
            'tablet_default' => [
                'size' => 1,
                'unit' => 'px',
            ],
            'mobile_default' => [
                'size' => 1,
                'unit' => 'px',
            ],
            'condition' => [
                'layout' => 'grid'
            ],
        ]);
        $this->add_responsive_control('slides_to_show', [
            'label' => __('Slide To Show', 'elementor'),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 1,
                    'max' => 10,
                ]
            ],
            'devices' => ['desktop', 'tablet', 'mobile'],
            'desktop_default' => [
                'size' => 1,
                'unit' => 'px',
            ],
            'tablet_default' => [
                'size' => 1,
                'unit' => 'px',
            ],
            'mobile_default' => [
                'size' => 1,
                'unit' => 'px',
            ],
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_control('scroll', [
            'label' => __('Slider to scroll', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '1',
            'description' => __('Number testimonial scroll per time.', 'cafe'),
            'condition' => [
                'layout' => 'carousel'
            ],

        ]);
        $this->add_responsive_control('show_nav', [
            'label' => __('Enable Navigation', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_responsive_control('show_pag', [
            'label' => __('Enable Pagination', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_responsive_control('autoplay', [
            'label' => __('Auto Play', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_control('speed', [
            'label' => __('Speed', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '3000',
            'condition' => [
                'layout' => 'carousel',
                'autoplay' => 'true'
            ],
            'description' => __('Time(ms) to next slider.', 'cafe'),
        ]);
        $this->add_control('show_avatar', [
            'label' => __('Show user avatar', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('show_des', [
            'label' => __('Show user description', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('show_star', [
            'label' => __('Show Star', 'cafe'),
            'description' => __('', 'cafe'),
            'type' => Controls_Manager::SWITCHER,
            'return_value' => 'true',
            'default' => 'false',
        ]);
        $this->add_control('css_class', [
            'label' => __('Custom HTML Class', 'cafe'),
            'type' => Controls_Manager::TEXT,
            'description' => __('You may add a custom HTML class to style element later.', 'cafe'),
        ]);
        $this->end_controls_section();
        $this->start_controls_section('heading_quotation_settings', [
            'label' => __('Quotation icon', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('quotation_color', [
            'label' => __('Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-quotation' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('quotation_bg_color', [
            'label' => __('Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-quotation' => 'background-color: {{VALUE}};'
            ]
        ]);
        $this->add_control('quotation_icon_size', [
            'label' => __('Icon Size', 'cafe'),
            'type' => Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-quotation' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_control('quotation_size', [
            'label' => __('Size', 'cafe'),
            'type' => Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-quotation' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_control('quotation_radius', [
            'label' => __('Border Radius', 'cafe'),
            'type' => Controls_Manager::SLIDER,
            'size_units' => ['px', '%'],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-quotation' => 'border-radius: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_control('quotation_spacing', [
            'label' => __('Spacing', 'cafe'),
            'type' => Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 200,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-quotation' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control(
            'quotation_align',
            [
                'label' => __('Align', 'cafe'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __('Left', 'cafe'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'none' => [
                        'title' => __('Center', 'cafe'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'cafe'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cafe-quotation' => 'float: {{VALUE}};'
                ]
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section('heading_content_block_settings', [
            'label' => __('Content Block', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('content_block_bg_color', [
            'label' => __('Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-content' => 'background-color: {{VALUE}};'
            ]
        ]);
        $this->add_responsive_control(
            'content_block_align',
            [
                'label' => __('Align', 'cafe'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __('Left', 'cafe'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'none' => [
                        'center' => __('Center', 'cafe'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'cafe'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cafe-wrap-content' => 'text-align: {{VALUE}};'
                ]
            ]
        );

        $this->add_control('content_block_border_radius', [
            'label' => __('Border Radius', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'separator' => 'before',
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'content_block_border',
                'label' => __('Border', 'cafe'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .cafe-wrap-content',
                'separator' => 'before',
            ]
        );
        $this->add_responsive_control('content_block_padding', [
            'label' => __('Padding', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('content_block_margin', [
            'label' => __('Margin', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->end_controls_section();
        $this->start_controls_section('heading_avatar_settings', [
            'label' => __('Avatar', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('avatar_size', [
            'label' => __('Size', 'cafe'),
            'type' => Controls_Manager::SLIDER,
            'size_units' => ['px'],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 300,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-avatar' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_control('avatar_bg_color', [
            'label' => __('Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-avatar' => 'background-color: {{VALUE}};'
            ]
        ]);

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'avatar_shadow',
                'selector' => '{{WRAPPER}} .cafe-wrap-avatar',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'avatar_border',
                'label' => __('Border', 'cafe'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .cafe-wrap-avatar',
                'separator' => 'before',
            ]
        );
        $this->add_control('avatar_border_radius', [
            'label' => __('Border Radius', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'separator' => 'before',
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-avatar' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('avatar_padding', [
            'label' => __('Padding', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-avatar' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('avatar_margin', [
            'label' => __('Margin', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-wrap-avatar' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->end_controls_section();
        $this->start_controls_section('heading_content_settings', [
            'label' => __('Content', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('content_color', [
            'label' => __('Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-content' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('content_bg_color', [
            'label' => __('Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-content' => 'background: {{VALUE}};',
                '{{WRAPPER}} .cafe-testimonial-content:after' => 'border-top-color: {{VALUE}};'
            ]
        ]);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typography',
                'selector' => '{{WRAPPER}} .cafe-testimonial-content',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'content_border',
                'label' => __('Border', 'cafe'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .cafe-testimonial-content',
                'separator' => 'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'content_shadow',
                'separator' => 'before',
                'selector' => '{{WRAPPER}} .cafe-testimonial-content',
            ]
        );
        $this->add_responsive_control('content_padding', [
            'label' => __('Padding', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'separator' => 'before',
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('content_margin', [
            'label' => __('Margin', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->end_controls_section();
        $this->start_controls_section('heading_author_settings', [
            'label' => __('Author', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('author_color', [
            'label' => __('Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-author' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'author_typography',
                'selector' => '{{WRAPPER}} .cafe-testimonial-author',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'author_border',
                'label' => __('Border', 'cafe'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .cafe-testimonial-author',
                'separator' => 'before',
            ]
        );
        $this->add_responsive_control('author_padding', [
            'label' => __('Padding', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'separator' => 'before',
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-author' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('author_margin', [
            'label' => __('Margin', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->end_controls_section();
        $this->start_controls_section('heading_des_settings', [
            'label' => __('Author Description', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('des_color', [
            'label' => __('Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-des' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'des_typography',
                'selector' => '{{WRAPPER}} .cafe-testimonial-des',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'des_border',
                'label' => __('Border', 'cafe'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .cafe-testimonial-des',
                'separator' => 'before',
            ]
        );
        $this->add_responsive_control('des_padding', [
            'label' => __('Padding', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'separator' => 'before',
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-des' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('des_margin', [
            'label' => __('Margin', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-des' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->end_controls_section();
        $this->start_controls_section('heading_star_settings', [
            'label' => __('Stars', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_control('base_star_color', [
            'label' => __('Base Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-rate .cafe-rate-star::before' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('star_color', [
            'label' => __('Rate Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-rate .cafe-rate-star::after' => 'color: {{VALUE}};'
            ]
        ]);

        $this->add_control('star_size', [
            'label' => __('Size', 'cafe'),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-rate .cafe-rate-star' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ]);
        $this->add_responsive_control('star_margin', [
            'label' => __('Margin', 'cafe'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%', 'em'],
            'selectors' => [
                '{{WRAPPER}} .cafe-testimonial-rate' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ]);
        $this->end_controls_section();
        $this->start_controls_section('slider_nav_settings', [
            'label' => __('Navigation & Pagination', 'cafe'),
            'tab' => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => 'carousel'
            ],
        ]);
        $this->add_control('slider_nav_color', [
            'label' => __('Navigation Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-carousel .cafe-carousel-btn' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('slider_pag_color', [
            'label' => __('Pagination Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-carousel ul.slick-dots li' => 'background: {{VALUE}};'
            ]
        ]);
        $this->add_control('slider_nav_hover_color_heading', [
            'label' => __('Hover & Active', 'cafe'),
            'type' => Controls_Manager::HEADING,
            'separator' => 'after',
        ]);

        $this->add_control('slider_nav_hover_color', [
            'label' => __('Navigation Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-carousel .cafe-carousel-btn:hover' => 'color: {{VALUE}};'
            ]
        ]);
        $this->add_control('slider_pag_hover_color', [
            'label' => __('Pagination Color', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-carousel ul.slick-dots li:hover,{{WRAPPER}} .cafe-carousel ul.slick-dots li.slick-active' => 'background: {{VALUE}};'
            ]
        ]);
        $this->end_controls_section();
    }

    /**
     * Load style
     */
    public function get_style_depends()
    {
        return ['cafe-style'];
    }

    /**
     * Retrieve the list of scripts the image carousel widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.3.0
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['jquery-slick', 'cafe-script'];
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
            'content' => '',
            'layout' => 'grid',
            'style' => 'default',
            'col' => 1,
            'show_quotation' => '',
            'show_des' => '',
            'show_nav' => '',
            'show_pag' => '',
            'show_avatar' => '',
            'show_star' => 'false',
            'autoplay' => '',
            'autoplay_speed' => '3000',
            'css_class' => '',

        ], $this->get_settings_for_display());


        $this->getViewTemplate('template', 'testimonial', $settings);
    }
}