<?php namespace CleverAddonsForElementor\Widgets;

use Elementor\Controls_Manager;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;

/**
 * Clever Video Light box
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 * @package CAFE
 */
final class CleverVideoLightBox extends CleverWidgetBase
{
    /**
     * @return string
     */
    function get_name()
    {
        return 'clever-video-light-box';
    }

    /**
     * @return string
     */
    function get_title()
    {
        return __('Clever Video Light Box', 'cafe');
    }

    /**
     * @return string
     */
    function get_icon()
    {
        return 'cs-font clever-icon-play-1';
    }

    /**
     * Register controls
     */
    protected function _register_controls()
    {
        $this->start_controls_section('settings', [
            'label' => __('Settings', 'cafe')
        ]);
        $this->add_control('source_url', [
            'label' => __('Video Emb URL', 'cafe'),
            'type' => Controls_Manager::URL,
        ]);
        $this->add_control('title', [
            'label' => __('Title', 'cafe'),
            'type' => Controls_Manager::TEXT,
            'dynamic' => ['active' => true],
            'label_block' => false
        ]);
        $this->add_control('des', [
            'label' => __('Description', 'cafe'),
            'type' => Controls_Manager::TEXTAREA,
            'dynamic' => ['active' => true],
            'label_block' => false
        ]);
        $this->add_control('image', [
            'label' => __('Video thumb', 'cafe'),
            'type' => Controls_Manager::MEDIA,
        ]);
        $this->add_control('width', [
            'label' => __('Video Width', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '800',
            'description' => __('Video Width in desktop', 'cafe'),
        ]);
        $this->add_control('height', [
            'label' => __('Video Height', 'cafe'),
            'type' => Controls_Manager::NUMBER,
            'default' => '450',
            'description' => __('Video height in desktop', 'cafe'),
        ]);

	    $this->add_control('css_class', [
		    'label' => __('Custom HTML Class', 'cafe'),
		    'type' => Controls_Manager::TEXT,
		    'description' => __('You may add a custom HTML class to style element later.', 'cafe'),
	    ]);
        $this->end_controls_section();

        $this->start_controls_section('block_style', [
            'label' => __('Style', 'cafe'),
            'tab'   => Controls_Manager::TAB_STYLE,
        ]);
        $this->add_responsive_control( 'button-align', [
            'label'                => __( 'Align', 'cafe' ),
            'type'                 => Controls_Manager::CHOOSE,
            'label_block'          => false,
            'options'              => [
                'left'   => [
                    'title' => __( 'Left', 'cafe' ),
                    'icon'  => 'eicon-h-align-left',
                ],
                'center' => [
                    'title' => __( 'Center', 'cafe' ),
                    'icon'  => 'eicon-h-align-center',
                ],
                'right'  => [
                    'title' => __( 'Right', 'cafe' ),
                    'icon'  => 'eicon-h-align-right',
                ],
            ],
            'selectors'            => [
                '{{WRAPPER}} .cafe-video-light-box .cafe-wrap-content-video' => '{{VALUE}}',
            ],
            'selectors_dictionary' => [
                'left'   => 'align-items: flex-start',
                'center' => 'align-items: center',
                'right'  => 'align-items: flex-end',
            ],
        ] );
        $this->add_control( 'button_type', [
            'label'     => __( 'Button Type', 'cafe' ),
            'type'      => Controls_Manager::SELECT,
            'default'   => 'round',
            'options'   => [
                'round'           => __( 'Round', 'cafe' ),
                'flat'          => __( 'Flat', 'cafe' ),
                ]
        ]);
        $this->add_responsive_control('button_size', [
            'label' => __('Size', 'cafe'),
            'type'      => Controls_Manager::SLIDER,
            'size_units' => [ 'px'],
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 2000,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .cafe-video-button .play' => 'height: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}}',
            ],
        ]);
        $this->add_control('color', [
            'label' => __('Color Button', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'default'=>'#fff',
            'selectors' => [
	            '{{WRAPPER}} .cafe-video-button path.icon' => 'fill: {{COLOR}}',
	            '{{WRAPPER}} .cafe-video-button path.stroke-solid, {{WRAPPER}} .cafe-video-button path.stroke-dotted' => 'stroke: {{COLOR}}',
            ],
        ]);
        $this->add_control('background', [
            'label' => __('Color Background', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'default'=>'',
            'selectors' => [
	            '{{WRAPPER}} .cafe-video-button .play, {{WRAPPER}} .cafe-video-button:before' => 'background: {{COLOR}}',
            ],
        ]);
        $this->add_responsive_control( 'button_margin', [
            'label'      => __( 'Button Margin', 'cafe' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', 'em', '%' ],
            'selectors'  => [
                '{{WRAPPER}} .cafe-video-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );
	    $this->add_control( 'title_style_heading', [
		    'label'     => __( 'Title', 'cafe' ),
		    'type'      => Controls_Manager::HEADING,
		    'separator' => 'before',
	    ] );
        $this->add_control('color_title', [
            'label' => __('Color Title', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-video-light-box .cafe-title' => 'color: {{COLOR}}',
            ],
        ]);
	    $this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
			    'name'     => 'title_typography',
			    'selector' => '{{WRAPPER}} .cafe-video-light-box .cafe-title',
			    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
		    ]
	    );
	    $this->add_control( 'des_style_heading', [
		    'label'     => __( 'Description', 'cafe' ),
		    'type'      => Controls_Manager::HEADING,
		    'separator' => 'before',
	    ] );
        $this->add_control('color_des', [
            'label' => __('Color Description', 'cafe'),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .cafe-video-light-box .cafe-description' => 'color: {{COLOR}}',
            ],
        ]);
	    $this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
			    'name'     => 'des_typography',
			    'selector' => '{{WRAPPER}} .cafe-video-light-box .cafe-description',
			    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
		    ]
	    );
        $this->add_responsive_control('block_height', [
            'label' => __('Height', 'cafe'),
            'type'      => Controls_Manager::SLIDER,
            'size_units' => [ 'px', 'vh'],
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 2000,
                ],
                'vh' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'separator' => 'before',
            'description' => __('Height for block', 'cafe'),
            'selectors' => [
                '{{WRAPPER}} .cafe-video-light-box' => 'height: {{SIZE}}{{UNIT}}',
            ],
        ]);
        $this->add_control('overlay_bg', [
            'label' => __('Overlay Background Color', 'cafe'),
            'type' => Controls_Manager::COLOR,

            'selectors' => [
                '{{WRAPPER}} .cafe-video-light-box .cafe-wrap-content-video' => 'background-color: {{COLOR}}',
            ],
        ]);
        $this->end_controls_section();
    }

    /**
     * Load style
     */
    public function get_style_depends()
    {
        return ['cafe-style'];
    }

    /**
     * Retrieve the list of scripts the image carousel widget depended on.
     *
     * Used to set scripts dependencies required to run the widget.
     *
     * @since 1.3.0
     * @access public
     *
     * @return array Widget scripts dependencies.
     */
    public function get_script_depends()
    {
        return ['cafe-script'];
    }

    /**
     * Render
     */
    protected function render()
    {
        $settings = array_merge([ // default settings
            'source_url' => '',
            'title' => '',
            'des' => '',
            'width' => '800',
            'height' => '450',
            'image' => '',
            'color' => '#fff',
            'button_type' => 'round',
            'css_class' => '',

        ], $this->get_settings_for_display());

        $this->add_inline_editing_attributes('title');
        $this->add_inline_editing_attributes('des');

        $this->getViewTemplate('template', 'video-light-box', $settings);
    }
}
