<?php

/**
 * Clever One Pixel
 *
 * @author CleverSoft <hello.cleversoft@gmail.com>
 */
final class CleverOnePixel {
    /**
     * Table suffix
     *
     * @var string
     */
    const TABLE_SUFFIX = 'clever_visitors_info';

    /**
     * Settings key
     *
     * @var string
     */
    const SETTINGS_KEY = 'cop_settings';

    /**
     * Known bots
     *
     * @var array
     */
    const BOTS = [
        'Google Bot'    => 'google',
        'MSN'           => 'msnbot',
        'BingBot'       => 'bingbot',
        'Alex'          => 'ia_archiver',
        'Lycos'         => 'lycos',
        'Ask Jeeves'    => 'jeeves',
        'Altavista'     => 'scooter',
        'AllTheWeb'     => 'fast-webcrawler',
        'Inktomi'       => 'slurp@inktomi',
        'Turnitin.com'  => 'turnitinbot',
        'Technorati'    => 'technorati',
        'Yahoo'         => 'yahoo',
        'Findexa'       => 'findexa',
        'NextLinks'     => 'findlinks',
        'Gais'          => 'gaisbo',
        'WiseNut'       => 'zyborg',
        'WhoisSource'   => 'surveybot',
        'Bloglines'     => 'bloglines',
        'BlogSearch'    => 'blogsearch',
        'PubSub'        => 'pubsub',
        'Syndic8'       => 'syndic8',
        'RadioUserland' => 'userland',
        'Gigabot'       => 'gigabot',
        'Become.com'    => 'become.com',
        'Baidu'         => 'baidu',
        'Yandex'        => 'yandex',
        'Amazon'        => 'amazonaws.com',
        'Ahrefs'        => 'AhrefsBot'
    ];
    static $fake;
    static $fake_max;

    /**
     * Nope constructor
     */
    private function __construct() {

    }

    /**
     * Singleton
     */
    static function instance() {
        static $self = null;
        if ( null === $self ) {
            $self           = new self();
            self::$fake     = intval( get_theme_mod( 'zoo_product_visitor_fake_data', 100 ) );
            self::$fake_max = intval( get_theme_mod( 'zoo_product_visitor_fake_max_data', 200 ) );
            if ( self::$fake <= 0 ) {
                add_action( 'wp_head', [ $self, '_run' ] );
                add_action( 'wp_ajax_cop_count_visitors', [ $self, 'countVisitors' ] );
                add_action( 'wp_ajax_nopriv_cop_count_visitors', [ $self, 'countVisitors' ] );
            }
            add_action( 'wp_footer', [ $self, '_scripts' ] );
        }
    }

    /**
     * Start track visitor
     *
     * @internal Used as a callback.
     */
    static function _run() {
        global $wpdb, $wp_query;

        if ( ! $wp_query->is_main_query() || empty( $wp_query->query_vars['post_type'] ) || 'product' !== $wp_query->query_vars['post_type'] ) {
            return;
        }

        $refer        = str_replace( [
            'http:',
            'https:'
        ], '', esc_url_raw( $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] ) );
        $table_name   = $wpdb->prefix . self::TABLE_SUFFIX;
        $visitor_ip   = self::getVisitorIp();
        $current_time = current_time( 'mysql' );

        $data = [
            'visitor_refer' => $refer,
            'visitor_time'  => $current_time,
        ];

        if ( $visitor_id = self::visitorExists( $visitor_ip, $refer ) ) {
            if ( $visitor_id ) {
                $wpdb->update( $table_name, $data, [ 'visitor_id' => $visitor_id ] );
            }
        } else {
            $data['visitor_ip'] = $visitor_ip;
            $wpdb->insert( $table_name, $data );
        }

        // Remove timeout visitors
        $wpdb->query( $wpdb->prepare( "DELETE FROM $table_name WHERE visitor_time < DATE_SUB(%s, INTERVAL %d SECOND)", $current_time, 300 ) );
    }

    /**
     * Get visitor's IP address
     */
    static function getVisitorIp() {
        if ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
            if ( false !== strpos( $_SERVER['HTTP_X_FORWARDED_FOR'], ',' ) ) {
                $addr = explode( ',', $_SERVER['HTTP_X_FORWARDED_FOR'] );
                if ( $ip_addr = filter_var( trim( $addr[0] ), FILTER_VALIDATE_IP ) ) {
                    return $ip_addr;
                }
            } else {
                return $_SERVER['HTTP_X_FORWARDED_FOR'];
            }
        } else {
            return $_SERVER['REMOTE_ADDR'];
        }
    }

    /**
     * Visitor exists?
     */
    static function visitorExists( $ip, $refer ) {
        global $wpdb;

        $ip    = filter_var( $ip, FILTER_VALIDATE_IP );
        $refer = esc_url_raw( $refer );

        if ( ! $ip ) {
            return false;
        }

        $tb = $wpdb->prefix . self::TABLE_SUFFIX;

        return $wpdb->get_var( sprintf( "SELECT visitor_id FROM $tb WHERE visitor_ip='%s' AND visitor_refer='%s'", $ip, $refer ) );
    }

    /**
     * Count visitors for a request
     */
    static function countVisitors( $req = false ) {
        if ( self::$fake <= 0 ) {
            global $wpdb;

            $tb  = $wpdb->prefix . self::TABLE_SUFFIX;
            $req = $req ? esc_url_raw( $req ) : esc_url_raw( $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] );

            $is_doing_ajax = ! empty( $_POST['cop_count_req'] );

            if ( $is_doing_ajax ) {
                $req = esc_url_raw( $_POST['cop_count_req'] );
            }

            $req = str_replace( [ 'http:', 'https:' ], '', $req );

            $count = $wpdb->get_var( sprintf( "SELECT COUNT(*) FROM $tb WHERE visitor_refer='%s'", $req ) );

            if ( $count ) {
                $return = '<span id="cop-visitors-count"  class="visitor" data-refer="' . $req . '">' . strval( $count ) . '</span>';
            } else {
                $return = '<span id="cop-visitors-count"  class="visitor" data-refer="' . $req . '">0</span>';
            }

            if ( $is_doing_ajax ) {
                exit( json_encode( [ 'html' => $return ] ) );
            } else {
                return $return;
            }
        } else {
            if ( self::$fake_max > self::$fake ) {
                $fake_visitor = rand( self::$fake, self::$fake_max );
                return '<span id="cop-visitors-count" class="visitor" data-fake="' . self::$fake . '"data-fake-max="' . self::$fake_max . '">' . $fake_visitor . '</span>';
            } else {
                return false;
            }
        }
    }

    /**
     *
     */
    static function _scripts() {
        echo "<script>jQuery(function($)
        {
             function countVisitors(el){
	                if(el.data('fake')<=0){
		                var data = {
		                    'action': 'cop_count_visitors',
		                    'cop_count_req': el.data('refer').replace(/http(s)?:/, '')
		                };
		
		                $.post(woocommerce_params.ajax_url, data, function(r) {
							el.text(JSON.stringify(r.html))
		                });
	                }else{
	                    let min = parseInt(el.text()) - 10;
	                    let max = parseInt(el.text()) + 10;
	                    let count=zoogetRandomArbitrary(min,max);
	                    if(count<el.data('fake')){
	                        count=el.data('fake');
	                    }if(count>el.data('fake_max')){
	                        count=el.data('fake_max');
	                    }
	                    el.text(count);
	                }
	            }
            function zoogetRandomArbitrary(min, max) {
			  	let count = parseInt(Math.random() * (max - min) + min);
			 	return count<1?1:count;
			}
            var copCount = $('#cop-visitors-count');
            if (copCount.length) {
        		setInterval(function() { countVisitors(copCount); }, 10000);
            }
        });</script>";
    }
}

CleverOnePixel::instance();
